FcCell class

Inheritance

Constructors

FcCell({Key? key, VoidCallback? onPressed, EdgeInsets? padding, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.start, required Widget label, Widget? content, Alignment contentAlignment = Alignment.centerRight, bool arrow = true, Widget? extra, bool border = true})
const

Properties

arrow → bool
是否显示右侧箭头
final
border → bool
是否显示边框
final
content → Widget?
内容
final
contentAlignment → Alignment
内容对齐方式
final
crossAxisAlignment → CrossAxisAlignment
交叉轴对齐方式
final
extra → Widget?
最右侧扩展内容
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → Widget
标题,必传
final
onPressed → VoidCallback?
点击事件回调
final
padding → EdgeInsets?
内边距
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _FcCellState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited