FcNavigationBarItem class

navbar元素数据

Constructors

FcNavigationBarItem({required Widget icon, String? label, Widget? activeIcon, Color? backgroundColor})
const

Properties

activeIcon → Widget
活跃图标
final
backgroundColor → Color?
背景色
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget
图标
final
label → String?
标题
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited